Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(805)

Unified Diff: pkg/compiler/lib/src/cps_ir/builtin_operator.dart

Issue 1685893002: cpsir: insert guard and force specialization for [] and []= (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/compiler/lib/src/cps_ir/type_propagation.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/compiler/lib/src/cps_ir/builtin_operator.dart
diff --git a/pkg/compiler/lib/src/cps_ir/builtin_operator.dart b/pkg/compiler/lib/src/cps_ir/builtin_operator.dart
index 2db4ac5bf62d70ee7a348e735609df5152f1abfd..59812db1e15ad5d7e42b6cb16fb08666e0b541dd 100644
--- a/pkg/compiler/lib/src/cps_ir/builtin_operator.dart
+++ b/pkg/compiler/lib/src/cps_ir/builtin_operator.dart
@@ -18,7 +18,7 @@ library builtin_operator;
/// In all cases, the word "null" refers to the Dart null object, corresponding
/// to both JS null and JS undefined.
///
/// Some operators, notably [IsFloor] and [IsNumberAndFloor], take "repeated"
/// arguments to reflect the number of times the given value is referenced
/// by the generated code. The tree IR needs to know the number of references
/// to safely propagate assignments.
@@ -133,7 +133,14 @@ enum BuiltinOperator {
/// The argument must be repeated 3 times.
///
/// Compiles to `typeof x === 'number' && Math.floor(x) === x`
- IsNumberAndFloor,
+ IsInteger,
+
+ /// Returns true if the argument is not an integer.
+ ///
+ /// The argument must be repeated 3 times.
+ ///
+ /// Compiles to `typeof x !== 'number' || Math.floor(x) !== x`
+ IsNotInteger,
/// Returns true if the argument is a fixed length Array.
///
« no previous file with comments | « no previous file | pkg/compiler/lib/src/cps_ir/type_propagation.dart » ('j') | no next file with comments »
@@ -18,7 +18,7 @@ library builtin_operator;
/// to both JS null and JS undefined.
///
-/// Some operators, notably [IsFloor] and [IsNumberAndFloor], take "repeated"
+/// Some operators, notably [IsFloor] and [IsInteger], take "repeated"
/// arguments to reflect the number of times the given value is referenced
/// by the generated code. The tree IR needs to know the number of references

Powered by Google App Engine
This is Rietveld 408576698